import { userService, UserService } from "../services/user"
import express, {Request, Response, Router} from 'express'
import IResponse from "../interfaces/IResponse"
import IUser from "../interfaces/IUser"
import { User } from "../models/mongo/User"



export class UserController {
    private service: UserService
    private router: Router
    constructor() {
        this.service = userService
        this.router = express.Router()
        this.router.get('/', this.getUsers)
        this.router.post('/', this.createUser)
        this.router.post('/login', this.login)
        this.router.get('/token', this.checkToken)


    }
    public getRouter = (): Router => {
        return this.router
    }
    private createUser = async (req: Request, res: Response): Promise<void> => {
        const response: IResponse<IUser | undefined> = await this.service.createUser(req.body)
        res.status(200).send(response)
    }

    public login = async (req: Request, res: Response): Promise<void> => {
        const response: IResponse<IUser | undefined> = await this.service.login(req.body)
        res.status(200).send(response)
    }

    public getUsers = async (req: Request, res: Response): Promise<void> => {
        const user = await User.findOne({token: req.get('Authorization')})
        if(!user) {
            res.status(200).send({
                isStatusOk: false,
                result: undefined,
                message: 'Not authorized'
            })
        } else {
            const response: IResponse<IUser[] | undefined> = await this.service.getUsers()
            res.status(200).send(response)
        }
    }

    public checkToken = async (req: Request, res: Response): Promise<void> => {

        const user = await User.findOne({token: req.get('Authorization')})

        console.log(user)
        if(!user) {
            res.status(200).send({
                isStatusOk: false,
                result: undefined,
                message: 'Not authorized'
            })
        } else {
            const response: IResponse<IUser | undefined> = {
                isStatusOK: true,
                result: user,
                message: 'Token is ok'
            }
            res.status(200).send(response)
        }
    }
}

export const userController = new UserController()